Coverage for numpy\matrixlib\__init__.py: 0%

# Coverage for numpy\matrixlib\__init__.py : 0%

## 6 statements 0 run 6 missing 0 excluded

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 2 3 4 5 6 7 8 9 10 11 12 | """Sub-package containing the matrix class and related functions. """ from __future__ import division, absolute_import, print_function from .defmatrix import * __all__ = defmatrix.__all__ from numpy._pytesttester import PytestTester test = PytestTester(__name__) del PytestTester